<?php
namespace Zeedhi\Framework\DataSource;

use Zeedhi\Framework\DTO\Row;
/**
 * Class DataSet
 *
 * Contain data|rows that a DataSource\Manager will persist, and all necessary meta-data about it.
 *
 * @package Zeedhi\Framework\DataSource
 */
class DataSet implements AssociatedWithDataSource{

    /** @var string */
    protected $dataSourceName;

    /** @var array */
    protected $rows;

    /** @var array */
    protected $pagination;

    /**
     * @param string $dataSourceName  The name of the dataSource of this data set.
     * @param array  $rows            Optional.
     * @param array  $pagination      Optional.
     */
    public function __construct(string $dataSourceName, array $rows = [], array $pagination = []) {
        $this->dataSourceName = $dataSourceName;
        $this->rows = $rows;
        $this->pagination = $pagination;
    }

    /**
     * Return name of table of this DataSet.
     *
     * @return string
     */
    public function getDataSourceName() : string {
        return $this->dataSourceName;
    }

    /**
     * Set name of the dataSource of this dataSet
     *
     * @param string $dataSourceName
     */
    public function setDataSourceName(string $dataSourceName)
    {
        $this->dataSourceName = $dataSourceName;
    }

    /**
     * Sets the rows of this dataSet.
     *
     * @param array $rows
     */
    public function setRows(array $rows) {
        $this->rows = $rows;
    }

    /**
     * Return the rows that is this DataSet.
     *
     * @return array
     */
    public function getRows() : array {
        return $this->rows;
    }

    /**
     * Add a new row on DataSet.
     *
     * @param array $row
     */
    public function addRow(array $row) {
        $this->rows[] = $row;
    }

    /**
     * Sets the pagination of this dataSet.
     *
     * @param array $dataSourceName
     */
    public function setPagination(array $pagination) {
        $this->pagination = $pagination;
    }

    /**
     * Returns the pagination array of this DataSet.
     *
     * @return array
     */
    public function getPagination() : array {
        return $this->pagination;
    }
}